@@ -27,6 +27,10 @@ $ python DebugLibrary.py
 > import library  String
 > get substring  helloworld  5  8
 < 'wor'
+> ${secs} =  Get Time  epoch
+<  ${secs} = 1474814470
+> Log to console  ${secs}
+1474814470
 > selenium  https://www.google.com  chrome
 import library  Selenium2Library
 open browser  https://www.google.com  chrome
@@ -39,6 +43,7 @@ from __future__ import print_function
 from robot.errors import HandlerExecutionFailed
 from robot.libraries.BuiltIn import BuiltIn
 from robot.api import logger
+from robot.variables import is_var
 import cmd
 import os
 import re
@@ -49,7 +54,7 @@ except ImportError:
     pass
 import sys
 
-__version__ = '0.7.1'
+__version__ = '0.8'
 
 KEYWORD_SEP = re.compile('  +|\t')
 
@@ -120,7 +125,8 @@ class DebugCmd(BaseCmd):
 
     def help_selenium(self):
         '''Help of Selenium command'''
-        print('Start a selenium 2 webdriver and open google.com or other url in firefox or other browser you expect.')
+        print('Start a selenium 2 webdriver and open google.com '
+              'or other url in firefox or other browser you expect.')
         print('selenium  [<url>]  [<browser>]')
 
     def default(self, line):
@@ -132,9 +138,17 @@ class DebugCmd(BaseCmd):
         try:
             u_command = command.decode("utf-8")
             keyword = KEYWORD_SEP.split(u_command)
-            result = self.rf_bi.run_keyword(*keyword)
-            if result:
-                print('< ', repr(result))
+            variable_name = keyword[0].rstrip('= ')
+
+            if is_var(variable_name):
+                variable_value = self.rf_bi.run_keyword(*keyword[1:])
+                self.rf_bi._variables.__setitem__(variable_name,
+                                                  variable_value)
+                print('< ', variable_name, '=', repr(variable_value))
+            else:
+                result = self.rf_bi.run_keyword(*keyword)
+                if result:
+                    print('< ', repr(result))
         except HandlerExecutionFailed as exc:
             print('< keyword: %s' % command)
             print('! %s' % exc.full_message)
@@ -155,8 +169,8 @@ class DebugLibrary(object):
         # support
         old_stdout = sys.stdout
         sys.stdout = sys.__stdout__
-        print(
-            '\n>>>>> Enter interactive shell, only accepted plain text format keyword.')
+        print('\n>>>>> Enter interactive shell, only accepted plain text '
+              'format keyword.')
         debug_cmd = DebugCmd()
         debug_cmd.cmdloop()
         print('\n>>>>> Exit shell.')
@@ -179,10 +193,13 @@ class DebugLibrary(object):
         remote_url = self.get_remote_url()
         session_id = self.get_session_id()
 
-        s = 'from selenium import webdriver;d=webdriver.Remote(command_executor="%s",desired_capabilities={});d.session_id="%s"' % (
-            remote_url,
-            session_id
-        )
+        s = 'from selenium import webdriver;' \
+            'd=webdriver.Remote(command_executor="%s",' \
+            'desired_capabilities={});' \
+            'd.session_id="%s"' % (
+                remote_url,
+                session_id
+            )
 
         logger.console("\nDEBUG FROM CONSOLE\n%s\n" % (s))
         logger.info(s)
